@@ -147,6 +147,7 @@ impl CacheHashData {
         parent_folder.as_ref().join("calculate_accounts_hash_cache")
     }
 
+    /// load from 'file_name' into 'accumulator'
     pub fn load<P: AsRef<Path> + std::fmt::Debug>(
         &self,
         file_name: &P,
@@ -181,10 +182,6 @@ impl CacheHashData {
         let mmap = CacheHashDataFile::load_map(&path)?;
         m1.stop();
         stats.read_us = m1.as_us();
-        let header_size = std::mem::size_of::<Header>() as u64;
-        if file_len < header_size {
-            return Err(std::io::Error::from(std::io::ErrorKind::UnexpectedEof));
-        }
 
         let cell_size = std::mem::size_of::<EntryType>() as u64;
         let mut cache_file = CacheHashDataFile {
@@ -195,10 +192,7 @@ impl CacheHashData {
         let header = cache_file.get_header_mut();
         let entries = header.count;
 
-        let capacity = cell_size * (entries as u64) + header_size;
-        if file_len < capacity {
-            return Err(std::io::Error::from(std::io::ErrorKind::UnexpectedEof));
-        }
+        let capacity = cell_size * (entries as u64) + std::mem::size_of::<Header>() as u64;
         cache_file.capacity = capacity;
         assert_eq!(
             capacity, file_len,
@@ -246,6 +240,7 @@ impl CacheHashData {
         Ok(())
     }
 
+    /// save 'data' to 'file_name'
     pub fn save(&self, file_name: &Path, data: &SavedTypeSlice) -> Result<(), std::io::Error> {
         let mut stats = CacheHashDataStats::default();
         let result = self.save_internal(file_name, data, &mut stats);
@@ -253,7 +248,7 @@ impl CacheHashData {
         result
     }
 
-    pub fn save_internal(
+    fn save_internal(
         &self,
         file_name: &Path,
         data: &SavedTypeSlice,
