@@ -24,6 +24,7 @@ pub struct TransactionCost {
     pub data_bytes_cost: u64,
     pub execution_cost: u64,
     pub account_data_size: u64,
+    pub is_simple_vote: bool,
 }
 
 impl Default for TransactionCost {
@@ -35,6 +36,7 @@ impl Default for TransactionCost {
             data_bytes_cost: 0u64,
             execution_cost: 0u64,
             account_data_size: 0u64,
+            is_simple_vote: false,
         }
     }
 }
@@ -53,6 +55,7 @@ impl TransactionCost {
         self.write_lock_cost = 0;
         self.data_bytes_cost = 0;
         self.execution_cost = 0;
+        self.is_simple_vote = false;
     }
 
     pub fn sum(&self) -> u64 {
@@ -90,6 +93,7 @@ impl CostModel {
         tx_cost.data_bytes_cost = self.get_data_bytes_cost(transaction);
         tx_cost.execution_cost = self.get_transaction_cost(transaction);
         tx_cost.account_data_size = self.calculate_account_data_size(transaction);
+        tx_cost.is_simple_vote = transaction.is_simple_vote_transaction();
 
         debug!("transaction {:?} has cost {:?}", transaction, tx_cost);
         tx_cost
